<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Permet d'ouvrir une session si le login et le mot de passe correspondent à ceux de la base.
 * Si l'authentification réussie, la variable de session loggedin doit contenir l'identifiant de l'uilisateur logué.
 *   
 * @author jub
 *
 */
class Sessions extends CI_Controller
{
	function __construct()
	{
		parent::__construct();

		$this->load->library('session');
		$this->load->library('doctrine');
		$this->load->helper('html');
		$this->load->helper('url');

	}

	/**
	 * Permet de charger le formulaire d'identification.
	 */
	function login()
	{
		$this->load->view("backoffice/templates/header_login");
		$this->load->view('backoffice/login_view');
		$this->load->view('backoffice/templates/footer');
		 
	}

	/**
	 * Permet de vérifier si l'authentification a réussie.
	 * Si l'authentification a réussie, la variable loggedin reçoit un tableau qui a la clef id associe l'id de l'utilisateur authentifié.
	 */
	function authenticate()
	{
		//recupére du formulaire d'authentification la valeur de login et password.
		$login = $this->input->get_post('login');
		$password = $this->input->get_post('password');
		//utilisation de dépôt d'utilisateur pour vérifier l'authentification
		$em = $this->doctrine->em;
		$utilisateurRepository = $em->getRepository('models\Utilisateur');
		$authOk=$utilisateurRepository->authenticate($login,$password);
		
		if ($authOk)
		{
			//l'id utilisateur est obtenu à partir de son login
			$utilisateur = $utilisateurRepository->findOneByLogin($login);
			//la variable de session loggedin contiend un tableau qui à la clef id associe l'identifiant de l'utilisateur qui vient de s'authentifier.
			$this->session->set_userdata('loggedin', array('id'=>$utilisateur->getId()) );
		}
		//Que l'authentification est réussie ou non, l'on est redirigé vers le contôleur Accueil qui via le controleur hérité vérifiera si l'authentification a réussie.
		redirect('/backoffice/accueil');
	}

	/**
	 * Libère la variable de session, loggedin, l'utilisateur n'est plus identifié.
	 */
	function logout()
	{
		$this->session->unset_userdata('loggedin');

		redirect('/');
	}
}

?>
