<?php
namespace models;


/**
 * Image
 *
 * @Table(name="image")
 * @Entity(repositoryClass="\models\repositories\ImageRepository")
 * @HasLifecycleCallbacks
 */
class Image
{
	/**
	 * url est choisie par le SGBD, elle est unique et sans extension
	 * @var string $url l'url de l'image
	 *
	 * @Column(name="url", type="integer", nullable=false)
	 * @Id
	 * @GeneratedValue(strategy="IDENTITY");
	 */
	private $url;

	/**
	 * @var string $description la description de l'image
	 *
	 * @Column(name="description", type="string", length=512, nullable=true)
	 */
	private $description;

	/**
	 * L'utilisateur propriétaire de l'image, l'association est réalisée en utilisant le login.
	 * @var Utilisateur 
	 *
	 * @ManyToOne(targetEntity="Utilisateur")
	 * @JoinColumns({
	 *   @JoinColumn(name="utilisateur", referencedColumnName="id", onDelete="Cascade")
	 * })
	 */
	private $utilisateur;

	/**
	 * Construit une image en choisissant la description et l'utilisateur propriétaire
	 * @param unknown_type $description la description de l'image
	 * @param unknown_type $utilisateur le propriétaire de l'image
	 */
	public function __construct( $description, $utilisateur) {
		$this->description = $description;
		$this->utilisateur = $utilisateur;
	}

	/**
	 * Permet de connaître l'url de l'image
	 * @return string l'url de l'image
	 */
	public function getURL(){
		return $this->url;
	}

	/**
	 * Permet de connaître la description de l'image
	 * @return string la description de l'image
	 */
	public function getDescription(){
		return $this->description;
	}

	/**
	 * Permet de modifier la description d'une image
	 * @param unknown_type $description la nouvelle description
	 */
	public function setDescription($description)
	{
		$this->description=$description;
	}

	/**
	 * Permet de supprimer les fichiers associés à l'url
	 * @preRemove
	 */
	public function deleteFile()
	{
		$gallery_path = realpath(APPPATH . '..'.DIRECTORY_SEPARATOR.'ressources'.DIRECTORY_SEPARATOR.'medias'.DIRECTORY_SEPARATOR.'images').DIRECTORY_SEPARATOR;
		$thumb_path = realpath(APPPATH . '..'.DIRECTORY_SEPARATOR.'ressources'.DIRECTORY_SEPARATOR.'medias'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'miniatures').DIRECTORY_SEPARATOR;
		foreach (glob($gallery_path.$this->url.'.*') as $filename) {
			unlink($filename);
		}
		foreach (glob($thumb_path.$this->url.'.*') as $filename) {
			unlink($filename);
		}
		
	}
}